@@ -106,15 +106,18 @@ fn display_help() {
 
 pub fn from_args(args: &[String]) -> Opt {
     let mut args_iter = args.iter();
-    args_iter.next(); // Skip self.
+    args_iter.next();
 
-    if let Some(potential_script_src) = args_iter.next() {
-        if common::script_src_to_absolute(Path::new(&potential_script_src)).is_ok() {
-            return Opt {
-                script_src: Some(potential_script_src.clone()),
-                args: args_iter.cloned().collect(),
-                cmd: None,
-            };
+    if let Some(script_src) = args_iter.next() {
+        let absolute_script_src = common::script_src_to_absolute(Path::new(&script_src));
+        if let Ok(absolute_script_src) = absolute_script_src {
+            if absolute_script_src.exists() {
+                return Opt {
+                    script_src: Some(absolute_script_src.to_string_lossy().into()),
+                    args: args_iter.cloned().collect(),
+                    cmd: None,
+                };
+            }
         }
     }
 
